==> zio-aws-lightsail_2.12-5.17.172.1-sources.jar: zio/aws/lightsail/model/UpdateContainerServiceRequest.scala <==
package zio.aws.lightsail.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.lightsail.model.primitives.{
  ContainerServiceScale,
  ContainerServiceName
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class UpdateContainerServiceRequest(
    serviceName: ContainerServiceName,
    power: Optional[zio.aws.lightsail.model.ContainerServicePowerName] =
      Optional.Absent,
    scale: Optional[ContainerServiceScale] = Optional.Absent,
    isDisabled: Optional[Boolean] = Optional.Absent,
    publicDomainNames: Optional[Map[String, Iterable[String]]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.UpdateContainerServiceRequest = {
    import UpdateContainerServiceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.UpdateContainerServiceRequest
      .builder()
      .serviceName(ContainerServiceName.unwrap(serviceName): java.lang.String)
      .optionallyWith(power.map(value => value.unwrap))(_.power)
      .optionallyWith(
        scale.map(value => ContainerServiceScale.unwrap(value): Integer)
      )(_.scale)
      .optionallyWith(isDisabled.map(value => value: java.lang.Boolean))(
        _.isDisabled
      )
      .optionallyWith(
        publicDomainNames.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> value.map { item =>
                item: java.lang.String
              }.asJavaCollection
            })
            .asJava
        )
      )(_.publicDomainNames)
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.UpdateContainerServiceRequest.ReadOnly =
    zio.aws.lightsail.model.UpdateContainerServiceRequest.wrap(buildAwsValue())
}
object UpdateContainerServiceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.UpdateContainerServiceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.UpdateContainerServiceRequest =
      zio.aws.lightsail.model.UpdateContainerServiceRequest(
        serviceName,
        power.map(value => value),
        scale.map(value => value),
        isDisabled.map(value => value),
        publicDomainNames.map(value => value)
      )
    def serviceName: ContainerServiceName
    def power: Optional[zio.aws.lightsail.model.ContainerServicePowerName]
    def scale: Optional[ContainerServiceScale]
    def isDisabled: Optional[Boolean]
    def publicDomainNames: Optional[Map[String, List[String]]]
    def getServiceName: ZIO[Any, Nothing, ContainerServiceName] =
      ZIO.succeed(serviceName)
    def getPower: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.ContainerServicePowerName
    ] = AwsError.unwrapOptionField("power", power)
    def getScale: ZIO[Any, AwsError, ContainerServiceScale] =
      AwsError.unwrapOptionField("scale", scale)
    def getIsDisabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("isDisabled", isDisabled)
    def getPublicDomainNames: ZIO[Any, AwsError, Map[String, List[String]]] =
      AwsError.unwrapOptionField("publicDomainNames", publicDomainNames)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.UpdateContainerServiceRequest
  ) extends zio.aws.lightsail.model.UpdateContainerServiceRequest.ReadOnly {
    override val serviceName: ContainerServiceName =
      zio.aws.lightsail.model.primitives
        .ContainerServiceName(impl.serviceName())
    override val power
        : Optional[zio.aws.lightsail.model.ContainerServicePowerName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.power())
        .map(value =>
          zio.aws.lightsail.model.ContainerServicePowerName.wrap(value)
        )
    override val scale: Optional[ContainerServiceScale] = zio.aws.core.internal
      .optionalFromNullable(impl.scale())
      .map(value =>
        zio.aws.lightsail.model.primitives.ContainerServiceScale(value)
      )
    override val isDisabled: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.isDisabled())
      .map(value => value: Boolean)
    override val publicDomainNames: Optional[Map[String, List[String]]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.publicDomainNames())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              (key: String) -> value.asScala.map { item =>
                item: String
              }.toList
            })
            .toMap
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.UpdateContainerServiceRequest
  ): zio.aws.lightsail.model.UpdateContainerServiceRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-lightsail_2.12-5.19.7.3-sources.jar: zio/aws/lightsail/model/UpdateContainerServiceRequest.scala <==
package zio.aws.lightsail.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.lightsail.model.primitives.{
  ContainerServiceScale,
  ContainerServiceName
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class UpdateContainerServiceRequest(
    serviceName: ContainerServiceName,
    power: Optional[zio.aws.lightsail.model.ContainerServicePowerName] =
      Optional.Absent,
    scale: Optional[ContainerServiceScale] = Optional.Absent,
    isDisabled: Optional[Boolean] = Optional.Absent,
    publicDomainNames: Optional[Map[String, Iterable[String]]] =
      Optional.Absent,
    privateRegistryAccess: Optional[
      zio.aws.lightsail.model.PrivateRegistryAccessRequest
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.UpdateContainerServiceRequest = {
    import UpdateContainerServiceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.UpdateContainerServiceRequest
      .builder()
      .serviceName(ContainerServiceName.unwrap(serviceName): java.lang.String)
      .optionallyWith(power.map(value => value.unwrap))(_.power)
      .optionallyWith(
        scale.map(value => ContainerServiceScale.unwrap(value): Integer)
      )(_.scale)
      .optionallyWith(isDisabled.map(value => value: java.lang.Boolean))(
        _.isDisabled
      )
      .optionallyWith(
        publicDomainNames.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> value.map { item =>
                item: java.lang.String
              }.asJavaCollection
            })
            .asJava
        )
      )(_.publicDomainNames)
      .optionallyWith(
        privateRegistryAccess.map(value => value.buildAwsValue())
      )(_.privateRegistryAccess)
      .build()
  }
  def asReadOnly
      : zio.aws.lightsail.model.UpdateContainerServiceRequest.ReadOnly =
    zio.aws.lightsail.model.UpdateContainerServiceRequest.wrap(buildAwsValue())
}
object UpdateContainerServiceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.UpdateContainerServiceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.UpdateContainerServiceRequest =
      zio.aws.lightsail.model.UpdateContainerServiceRequest(
        serviceName,
        power.map(value => value),
        scale.map(value => value),
        isDisabled.map(value => value),
        publicDomainNames.map(value => value),
        privateRegistryAccess.map(value => value.asEditable)
      )
    def serviceName: ContainerServiceName
    def power: Optional[zio.aws.lightsail.model.ContainerServicePowerName]
    def scale: Optional[ContainerServiceScale]
    def isDisabled: Optional[Boolean]
    def publicDomainNames: Optional[Map[String, List[String]]]
    def privateRegistryAccess: Optional[
      zio.aws.lightsail.model.PrivateRegistryAccessRequest.ReadOnly
    ]
    def getServiceName: ZIO[Any, Nothing, ContainerServiceName] =
      ZIO.succeed(serviceName)
    def getPower: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.ContainerServicePowerName
    ] = AwsError.unwrapOptionField("power", power)
    def getScale: ZIO[Any, AwsError, ContainerServiceScale] =
      AwsError.unwrapOptionField("scale", scale)
    def getIsDisabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("isDisabled", isDisabled)
    def getPublicDomainNames: ZIO[Any, AwsError, Map[String, List[String]]] =
      AwsError.unwrapOptionField("publicDomainNames", publicDomainNames)
    def getPrivateRegistryAccess: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.PrivateRegistryAccessRequest.ReadOnly
    ] =
      AwsError.unwrapOptionField("privateRegistryAccess", privateRegistryAccess)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.UpdateContainerServiceRequest
  ) extends zio.aws.lightsail.model.UpdateContainerServiceRequest.ReadOnly {
    override val serviceName: ContainerServiceName =
      zio.aws.lightsail.model.primitives
        .ContainerServiceName(impl.serviceName())
    override val power
        : Optional[zio.aws.lightsail.model.ContainerServicePowerName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.power())
        .map(value =>
          zio.aws.lightsail.model.ContainerServicePowerName.wrap(value)
        )
    override val scale: Optional[ContainerServiceScale] = zio.aws.core.internal
      .optionalFromNullable(impl.scale())
      .map(value =>
        zio.aws.lightsail.model.primitives.ContainerServiceScale(value)
      )
    override val isDisabled: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.isDisabled())
      .map(value => value: Boolean)
    override val publicDomainNames: Optional[Map[String, List[String]]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.publicDomainNames())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              (key: String) -> value.asScala.map { item =>
                item: String
              }.toList
            })
            .toMap
        )
    override val privateRegistryAccess: Optional[
      zio.aws.lightsail.model.PrivateRegistryAccessRequest.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.privateRegistryAccess())
      .map(value =>
        zio.aws.lightsail.model.PrivateRegistryAccessRequest.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.UpdateContainerServiceRequest
  ): zio.aws.lightsail.model.UpdateContainerServiceRequest.ReadOnly =
    new Wrapper(impl)
}
